@@ -100,16 +100,6 @@ static void SetWorkStateInfo(hb_job_t *job)
     hb_set_state( job->h, &state );
 }
 
-static void sanitize_multipass(hb_job_t *job)
-{
-    int bit_depth = hb_get_bit_depth(job->title->pix_fmt);
-    if (job->vcodec == HB_VCODEC_FFMPEG_FFV1 && bit_depth > 8)
-    {
-        hb_log("FFV1 2-pass is not supported for bit depth higher than 8, disabling");
-        job->multipass = 0;
-    }
-}
-
 /**
  * Iterates through job list and calls do_job for each job.
  * @param _work Handle work object.
@@ -165,8 +155,6 @@ static void work_func( void * _work )
         }
 #endif
 
-
-        sanitize_multipass(job);
         hb_job_setup_passes(job->h, job, passes);
         hb_job_close(&job);
 
@@ -344,6 +332,10 @@ hb_work_object_t* hb_video_encoder(hb_handle_t *h, int vcodec)
             w = hb_get_work(h, WORK_ENCAVCODEC);
             w->codec_param = AV_CODEC_ID_HEVC;
             break;
+        case HB_VCODEC_FFMPEG_MF_AV1:
+            w = hb_get_work(h, WORK_ENCAVCODEC);
+            w->codec_param = AV_CODEC_ID_AV1;
+            break;
 #endif
         case HB_VCODEC_SVT_AV1:
         case HB_VCODEC_SVT_AV1_10BIT:
@@ -362,19 +354,18 @@ hb_work_object_t* hb_video_encoder(hb_handle_t *h, int vcodec)
 
 hb_work_object_t* hb_audio_encoder(hb_handle_t *h, int codec)
 {
-    if (codec & HB_ACODEC_FF_MASK)
-    {
-        return hb_get_work(h, WORK_ENCAVCODEC_AUDIO);
-    }
     switch (codec)
     {
-        case HB_ACODEC_AC3:
         case HB_ACODEC_LAME:    return hb_get_work(h, WORK_ENCAVCODEC_AUDIO);
         case HB_ACODEC_VORBIS:  return hb_get_work(h, WORK_ENCVORBIS);
         case HB_ACODEC_CA_AAC:  return hb_get_work(h, WORK_ENC_CA_AAC);
         case HB_ACODEC_CA_HAAC: return hb_get_work(h, WORK_ENC_CA_HAAC);
         default:                break;
     }
+    if (codec & HB_ACODEC_FF_MASK)
+    {
+        return hb_get_work(h, WORK_ENCAVCODEC_AUDIO);
+    }
     return NULL;
 }
 
@@ -612,6 +603,7 @@ void hb_display_job_info(hb_job_t *job)
                 case HB_VCODEC_VT_H265_10BIT:
                 case HB_VCODEC_FFMPEG_MF_H264:
                 case HB_VCODEC_FFMPEG_MF_H265:
+                case HB_VCODEC_FFMPEG_MF_AV1:
                 case HB_VCODEC_SVT_AV1:
                 case HB_VCODEC_SVT_AV1_10BIT:
                     hb_log("     + profile: %s", job->encoder_profile);
@@ -730,7 +722,7 @@ void hb_display_job_info(hb_job_t *job)
     if (job->indepth_scan)
     {
         hb_log( " * Foreign Audio Search: %s%s%s",
-                job->select_subtitle_config.dest == RENDERSUB ? "Render/Burn-in" : "Passthrough",
+                job->select_subtitle_config.dest == RENDERSUB ? "Render/Burn-in" : "Passthru",
                 job->select_subtitle_config.force ? ", Forced Only" : "",
                 job->select_subtitle_config.default_track ? ", Default" : "" );
     }
@@ -755,7 +747,7 @@ void hb_display_job_info(hb_job_t *job)
                        subtitle->out_track, subtitle->lang, subtitle->track,
                        subtitle->id,
                        subtitle->config.dest == RENDERSUB ? "Render/Burn-in"
-                                                          : "Passthrough",
+                                                          : "Passthru",
                        subtitle->config.default_track ? ", Default" : "",
                        subtitle->config.offset, subtitle->config.src_codeset);
             }
@@ -767,7 +759,7 @@ void hb_display_job_info(hb_job_t *job)
                        subtitle->out_track, subtitle->lang, subtitle->track,
                        subtitle->id,
                        subtitle->config.dest == RENDERSUB ? "Render/Burn-in"
-                                                          : "Passthrough",
+                                                          : "Passthru",
                        subtitle->config.default_track ? ", Default" : "",
                        subtitle->config.offset);
             }
@@ -779,7 +771,7 @@ void hb_display_job_info(hb_job_t *job)
                        subtitle->id,
                        subtitle->format == PICTURESUB ? "Picture" : "Text",
                        subtitle->config.dest == RENDERSUB ? "Render/Burn-in"
-                                                          : "Passthrough",
+                                                          : "Passthru",
                        subtitle->config.force ? ", Forced Only" : "",
                        subtitle->config.default_track ? ", Default" : "" );
             }
@@ -1540,6 +1532,16 @@ static void sanitize_dynamic_hdr_metadata_passthru(hb_job_t *job)
         job->passthru_dynamic_hdr_metadata &= ~DOVI;
     }
 
+    if ((job->dovi.dv_profile == 8 || job->dovi.dv_profile == 10) &&
+        job->dovi.dv_bl_signal_compatibility_id == 1)
+    {
+        if (job->mastering.has_primaries == 0 && job->mastering.has_luminance == 0)
+        {
+            hb_log("work: missing mastering metadata, disabling Dolby Vision");
+            job->passthru_dynamic_hdr_metadata &= ~DOVI;
+        }
+    }
+
     if (job->passthru_dynamic_hdr_metadata & DOVI)
     {
 #if HB_PROJECT_FEATURE_LIBDOVI
@@ -1683,6 +1685,10 @@ static void do_job(hb_job_t *job)
     {
         job->hw_decode = 0;
     }
+    if (job->hw_decode == HB_DECODE_SUPPORT_MF)
+    {
+        job->hw_decode |= HB_DECODE_SUPPORT_FORCE_HW;
+    }
 
     // This must be performed before initializing filters because
     // it can add the subtitle render filter.
@@ -1947,7 +1953,7 @@ static void do_job(hb_job_t *job)
             if ( !(audio->config.out.codec & HB_ACODEC_PASS_FLAG ) )
             {
                 /*
-                * Add the encoder thread if not doing pass through
+                * Add the encoder thread if not doing passthru
                 */
                 w = hb_audio_encoder( job->h, audio->config.out.codec);
                 if (w == NULL)
